Translate Toolkit 3.3.5 — Translate Toolkit 3.5.2 documentation

# Translate Toolkit 3.3.5

Released on 27 April 2021

This release contains improvements and bug fixes.

## Changes

### Formats and Converters

- PO

  - Improve newline char detection

- Properties

  - performance improvements

  - consolidated API between dialects

- QT ts2

  - Consistent using of XML entity for non-breakable space

## Contributors

This release was made possible by the following people:

Michal Čihař